@@ -46,6 +46,9 @@ class GitLabProjects(GitLabCore):
     def get_deploy_key(self, project_and_group_name, id):
         return self._make_requests_to_api("projects/%s/deploy_keys/%s", (project_and_group_name, id), 'GET')
 
+    def delete_secret_variable(self, project_and_group_name, secret_variable_key):
+        self._make_requests_to_api("projects/%s/variables/%s", (project_and_group_name, secret_variable_key), method='DELETE', expected_codes=[204,404])
+
     def post_secret_variable(self, project_and_group_name, secret_variable):
         # secret_variable has to be like documented at:
         # https://docs.gitlab.com/ee/api/project_level_variables.html#create-variable
