@@ -6,11 +6,13 @@ import sys
 from pathlib import Path
 import os
 from functools import wraps
+import luddite
+import pkg_resources
 
 from gitlabform.configuration import Configuration
 from gitlabform.configuration.core import ConfigFileNotFoundException
 from gitlabform.gitlab import GitLab
-from gitlabform.gitlab.core import TestRequestFailedException, UnexpectedResponseException
+from gitlabform.gitlab.core import TestRequestFailedException
 from gitlabform.gitlab.core import NotFoundException
 
 
@@ -99,18 +101,22 @@ class GitLabFormCore(object):
             self.start_from = 1
             self.noop = False
             self.set_log_level(tests=True)
+            self.skip_version_check = True
         else:
-            self.project_or_group, self.config, self.verbose, self.debug, self.strict, self.start_from, self.noop \
-                = self.parse_args()
+            self.project_or_group, self.config, self.verbose, self.debug, self.strict, self.start_from, self.noop, \
+                self.skip_version_check = self.parse_args()
             self.set_log_level()
+            print(self.get_version(self.skip_version_check))
 
         self.gl, self.c = self.initialize_configuration_and_gitlab()
 
     def parse_args(self):
 
-        parser = argparse.ArgumentParser(description='Easy configuration as code tool for GitLab'
-                                                     ' using config in plain YAML.',
-                                         formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+        parser = argparse.ArgumentParser(
+            description='Specialized "configuration as a code" tool for GitLab projects, groups and more'
+                        ' using hierarchical configuration written in YAML',
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter
+        )
 
         parser.add_argument('project_or_group',
                             help='Project name in "group/project" format'
@@ -134,9 +140,15 @@ class GitLabFormCore(object):
 
         parser.add_argument('-n', '--noop', dest='noop', action="store_true", help='Run in no-op (dry run) mode')
 
+        parser.add_argument('-V', '--version', action='version', version=self.get_version(False))
+
+        parser.add_argument('-k', '--skip-version-check', dest='skip_version_check', action="store_true",
+                            help="Skips checking if the latest version is used")
+
         args = parser.parse_args()
 
-        return args.project_or_group, args.config, args.verbose, args.debug, args.strict, args.start_from, args.noop
+        return args.project_or_group, args.config, args.verbose, args.debug, args.strict, args.start_from, args.noop, \
+            args.skip_version_check
 
     def set_log_level(self, tests=False):
 
@@ -156,6 +168,19 @@ class GitLabFormCore(object):
             handler = logging.getLogger().handlers[0]
             logging.getLogger().removeHandler(handler)
 
+    def get_version(self, skip_version_check):
+        local_version = pkg_resources.get_distribution('gitlabform').version
+        version = f'GitLabForm version: {local_version}'
+
+        if not skip_version_check:
+            latest_version = luddite.get_version_pypi('gitlabform')
+            if local_version == latest_version:
+                version += ' (the latest)'
+            else:
+                version += f' (the latest is {latest_version} - please update!)'
+
+        return version
+
     def initialize_configuration_and_gitlab(self):
 
         try:
@@ -411,9 +436,20 @@ class GitLabFormCore(object):
             return
 
         logging.debug("Secret variables BEFORE: %s", self.gl.get_secret_variables(project_and_group))
-        for secret_variable in sorted(configuration['secret_variables']):
-            logging.info("Setting secret variable: %s", secret_variable)
 
+        for secret_variable in sorted(configuration['secret_variables']):
+
+            if "delete" in configuration['secret_variables'][secret_variable]:
+                key = configuration['secret_variables'][secret_variable]["key"]
+                if configuration['secret_variables'][secret_variable]["delete"]:
+                    logging.info(f"Deleting {secret_variable}: {key} in project {project_and_group}")
+                    try:
+                        self.gl.delete_secret_variable(project_and_group, key)
+                    except:
+                        logging.warn(f"Could not delete variable {key} in group {project_and_group}")
+                    continue
+
+            logging.info("Setting secret variable: %s", secret_variable)
             try:
                 self.gl.put_secret_variable(project_and_group, configuration['secret_variables'][secret_variable])
             except NotFoundException:
@@ -424,9 +460,20 @@ class GitLabFormCore(object):
     @if_in_config_and_not_skipped
     def process_group_secret_variables(self, group, configuration):
         logging.debug("Group secret variables BEFORE: %s", self.gl.get_group_secret_variables(group))
-        for secret_variable in sorted(configuration['group_secret_variables']):
-            logging.info("Setting group secret variable: %s", secret_variable)
 
+        for secret_variable in sorted(configuration['group_secret_variables']):
+
+            if "delete" in configuration['group_secret_variables'][secret_variable]:
+                key = configuration['group_secret_variables'][secret_variable]["key"]
+                if configuration['group_secret_variables'][secret_variable]["delete"]:
+                    logging.info(f"Deleting {secret_variable}: {key} in group {group}")
+                    try:
+                        self.gl.delete_group_secret_variable(group, key)
+                    except:
+                        logging.warn(f"Could not delete variable {key} in group {group}")
+                    continue
+
+            logging.info("Setting group secret variable: %s", secret_variable)
             try:
                 self.gl.put_group_secret_variable(group, configuration['group_secret_variables'][secret_variable])
             except NotFoundException:
